pub fn feature_summary() -> FeatureSummaryExpand description
Return the current feature summary shown by the CLI and exposed via MCP.
pub fn feature_summary() -> FeatureSummaryReturn the current feature summary shown by the CLI and exposed via MCP.