pub struct AsyncApiValidationSummary {
pub spec_version: String,
pub title: String,
pub api_version: String,
pub primary_protocol: String,
pub channel_count: usize,
}Expand description
Result of AsyncAPI validation exposed to both CLI and MCP surfaces.
Fields
spec_version: Stringtitle: Stringapi_version: Stringprimary_protocol: Stringchannel_count: usizeTrait Implementations
Sourceimpl Clone for AsyncApiValidationSummary
impl Clone for AsyncApiValidationSummary
Sourcefn clone(&self) -> AsyncApiValidationSummary
fn clone(&self) -> AsyncApiValidationSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AsyncApiValidationSummary
impl Debug for AsyncApiValidationSummary
Sourceimpl JsonSchema for AsyncApiValidationSummary
impl JsonSchema for AsyncApiValidationSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AsyncApiValidationSummary
impl RefUnwindSafe for AsyncApiValidationSummary
impl Send for AsyncApiValidationSummary
impl Sync for AsyncApiValidationSummary
impl Unpin for AsyncApiValidationSummary
impl UnsafeUnpin for AsyncApiValidationSummary
impl UnwindSafe for AsyncApiValidationSummary