pub struct FeatureSummary {
pub rust_core: bool,
pub language_bindings: Vec<LanguageBinding>,
pub documentation_url: String,
}Expand description
Human-readable framework capability summary for agents and CLI users.
Fields
rust_core: boollanguage_bindings: Vec<LanguageBinding>documentation_url: StringTrait Implementations
Sourceimpl Clone for FeatureSummary
impl Clone for FeatureSummary
Sourceimpl Debug for FeatureSummary
impl Debug for FeatureSummary
Sourceimpl JsonSchema for FeatureSummary
impl JsonSchema for FeatureSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FeatureSummary
impl RefUnwindSafe for FeatureSummary
impl Send for FeatureSummary
impl Sync for FeatureSummary
impl Unpin for FeatureSummary
impl UnsafeUnpin for FeatureSummary
impl UnwindSafe for FeatureSummary