pub struct LanguageBinding {
pub name: String,
pub install_hint: String,
pub usage_hint: String,
}Expand description
Install and usage hint for a supported binding.
Fields
name: Stringinstall_hint: Stringusage_hint: StringTrait Implementations
Sourceimpl Clone for LanguageBinding
impl Clone for LanguageBinding
Sourceimpl Debug for LanguageBinding
impl Debug for LanguageBinding
Sourceimpl JsonSchema for LanguageBinding
impl JsonSchema for LanguageBinding
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LanguageBinding
impl RefUnwindSafe for LanguageBinding
impl Send for LanguageBinding
impl Sync for LanguageBinding
impl Unpin for LanguageBinding
impl UnsafeUnpin for LanguageBinding
impl UnwindSafe for LanguageBinding