pub enum TargetLanguage {
Python,
TypeScript,
Rust,
Ruby,
Php,
}Expand description
Target programming language for identifier sanitization.
Variants
Implementations
Sourceimpl TargetLanguage
impl TargetLanguage
Sourcepub const fn reserved_keywords(self) -> &'static [&'static str]
pub const fn reserved_keywords(self) -> &'static [&'static str]
Get the reserved keywords for this language.
Sourcepub const fn soft_keywords(self) -> &'static [&'static str]
pub const fn soft_keywords(self) -> &'static [&'static str]
Get the reserved soft keywords that may be contextual for this language.
Sourcepub const fn keyword_prefix(self) -> &'static str
pub const fn keyword_prefix(self) -> &'static str
Get the keyword prefix for this language.
When a reserved keyword is used as an identifier, it’s prefixed with this character(s).