pub struct GeneratedAsset {
pub path: PathBuf,
pub description: String,
}Expand description
Represents an asset emitted by the code generation engine
Fields
path: PathBufdescription: StringTrait Implementations
Sourceimpl Clone for GeneratedAsset
impl Clone for GeneratedAsset
Sourceimpl Debug for GeneratedAsset
impl Debug for GeneratedAsset
Sourceimpl JsonSchema for GeneratedAsset
impl JsonSchema for GeneratedAsset
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GeneratedAsset
impl RefUnwindSafe for GeneratedAsset
impl Send for GeneratedAsset
impl Sync for GeneratedAsset
impl Unpin for GeneratedAsset
impl UnsafeUnpin for GeneratedAsset
impl UnwindSafe for GeneratedAsset